abacusai.hosted_artifact — AbacusAI documentation

# abacusai.hosted_artifact

## Classes

`HostedArtifact` | A hosted artifact being served by the platform.

## Module Contents

class abacusai.hosted_artifact.HostedArtifact(client, hostname=None, artifactType=None, llmArtifactId=None, lifecycle=None, externalApplicationId=None, deploymentConversationId=None, conversationSequenceNumber=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A hosted artifact being served by the platform.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - hostname (str) – The url at which the application is being hosted.

    - artifactType (str) – The type of artifact being hosted.

    - llmArtifactId (str) – The artifact id being hosted.

    - lifecycle (str) – The lifecycle of the artifact.

    - externalApplicationId (str) – Agent that deployed this application.

    - deploymentConversationId (str) – Conversation that created deployed this artifact, null if not applicable.

    - conversationSequenceNumber (number(integer)) – Conversation event associated with this artifact, null if not applicable.

  hostname = None
  artifact_type = None
  llm_artifact_id = None
  lifecycle = None
  external_application_id = None
  deployment_conversation_id = None
  conversation_sequence_number = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict